# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file '/home/super/PycharmProjects/IDAT/choice_label_dialog.ui'
#
# Created by: PyQt5 UI code generator 5.15.7
#
# WARNING: Any manual changes made to this file will be lost when pyuic5 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_Dialog_Choice_Label(object):
    def setupUi(self, Dialog_Choice_Label):
        Dialog_Choice_Label.setObjectName("Dialog_Choice_Label")
        Dialog_Choice_Label.resize(300, 350)
        font = QtGui.QFont()
        font.setFamily("Times New Roman")
        font.setPointSize(12)
        font.setBold(False)
        font.setItalic(False)
        font.setWeight(50)
        Dialog_Choice_Label.setFont(font)
        self.verticalLayout = QtWidgets.QVBoxLayout(Dialog_Choice_Label)
        self.verticalLayout.setSpacing(6)
        self.verticalLayout.setObjectName("verticalLayout")
        self.listWidget_category = QtWidgets.QListWidget(Dialog_Choice_Label)
        self.listWidget_category.setObjectName("listWidget_category")
        self.verticalLayout.addWidget(self.listWidget_category)
        self.lineEdit_category = QtWidgets.QLineEdit(Dialog_Choice_Label)
        self.lineEdit_category.setReadOnly(True)
        self.lineEdit_category.setObjectName("lineEdit_category")
        self.verticalLayout.addWidget(self.lineEdit_category)
        self.widget = QtWidgets.QWidget(Dialog_Choice_Label)
        self.widget.setObjectName("widget")
        self.horizontalLayout_2 = QtWidgets.QHBoxLayout(self.widget)
        self.horizontalLayout_2.setContentsMargins(0, 0, 0, 0)
        self.horizontalLayout_2.setSpacing(0)
        self.horizontalLayout_2.setObjectName("horizontalLayout_2")
        self.verticalLayout.addWidget(self.widget)
        self.horizontalLayout = QtWidgets.QHBoxLayout()
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.horizontalLayout_3 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_3.setObjectName("horizontalLayout_3")
        self.checkBox_difficult = QtWidgets.QCheckBox(Dialog_Choice_Label)
        self.checkBox_difficult.setObjectName("checkBox_difficult")
        self.horizontalLayout_3.addWidget(self.checkBox_difficult)
        self.horizontalLayout.addLayout(self.horizontalLayout_3)
        spacerItem = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout.addItem(spacerItem)
        self.pushButton_cache = QtWidgets.QPushButton(Dialog_Choice_Label)
        self.pushButton_cache.setMinimumSize(QtCore.QSize(80, 0))
        self.pushButton_cache.setMaximumSize(QtCore.QSize(80, 16777215))
        icon = QtGui.QIcon()
        icon.addPixmap(QtGui.QPixmap(":/icons/icons/关闭_close-one.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.pushButton_cache.setIcon(icon)
        self.pushButton_cache.setObjectName("pushButton_cache")
        self.horizontalLayout.addWidget(self.pushButton_cache)
        self.pushButton_apply = QtWidgets.QPushButton(Dialog_Choice_Label)
        self.pushButton_apply.setMinimumSize(QtCore.QSize(80, 0))
        self.pushButton_apply.setMaximumSize(QtCore.QSize(80, 16777215))
        icon1 = QtGui.QIcon()
        icon1.addPixmap(QtGui.QPixmap(":/icons/icons/校验_check-one.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.pushButton_apply.setIcon(icon1)
        self.pushButton_apply.setObjectName("pushButton_apply")
        self.horizontalLayout.addWidget(self.pushButton_apply)
        self.verticalLayout.addLayout(self.horizontalLayout)

        self.retranslateUi(Dialog_Choice_Label)
        QtCore.QMetaObject.connectSlotsByName(Dialog_Choice_Label)

    def retranslateUi(self, Dialog_Choice_Label):
        _translate = QtCore.QCoreApplication.translate
        Dialog_Choice_Label.setWindowTitle(_translate("Dialog_Choice_Label", "Choice Label"))
        self.checkBox_difficult.setText(_translate("Dialog_Choice_Label", "difficult"))
        self.pushButton_cache.setText(_translate("Dialog_Choice_Label", "cache"))
        self.pushButton_apply.setText(_translate("Dialog_Choice_Label", "apply"))
