# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file '/home/lg/PycharmProjects/IDAT/IDAT/ui/main_window.ui'
#
# Created by: PyQt5 UI code generator 5.15.10
#
# WARNING: Any manual changes made to this file will be lost when pyuic5 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_MainWindow(object):
    def setupUi(self, MainWindow):
        MainWindow.setObjectName("MainWindow")
        MainWindow.resize(1200, 720)
        font = QtGui.QFont()
        font.setFamily("Times New Roman")
        font.setPointSize(12)
        font.setBold(False)
        font.setItalic(False)
        font.setWeight(50)
        MainWindow.setFont(font)
        self.centralwidget = QtWidgets.QWidget(MainWindow)
        self.centralwidget.setObjectName("centralwidget")
        self.gridLayout = QtWidgets.QGridLayout(self.centralwidget)
        self.gridLayout.setContentsMargins(0, 0, 0, 0)
        self.gridLayout.setObjectName("gridLayout")
        MainWindow.setCentralWidget(self.centralwidget)
        self.menubar = QtWidgets.QMenuBar(MainWindow)
        self.menubar.setGeometry(QtCore.QRect(0, 0, 1200, 29))
        self.menubar.setObjectName("menubar")
        self.menuFile = QtWidgets.QMenu(self.menubar)
        font = QtGui.QFont()
        font.setFamily("Times New Roman")
        font.setPointSize(10)
        font.setBold(False)
        font.setItalic(False)
        font.setWeight(50)
        self.menuFile.setFont(font)
        self.menuFile.setObjectName("menuFile")
        self.menuView = QtWidgets.QMenu(self.menubar)
        self.menuView.setObjectName("menuView")
        self.menuEdit = QtWidgets.QMenu(self.menubar)
        self.menuEdit.setObjectName("menuEdit")
        self.menuHelp = QtWidgets.QMenu(self.menubar)
        self.menuHelp.setObjectName("menuHelp")
        self.menuLanguage = QtWidgets.QMenu(self.menuHelp)
        font = QtGui.QFont()
        font.setFamily("Times New Roman")
        font.setPointSize(12)
        font.setBold(False)
        font.setItalic(False)
        font.setWeight(50)
        self.menuLanguage.setFont(font)
        icon = QtGui.QIcon()
        icon.addPixmap(QtGui.QPixmap(":/icons/icons/翻译_translate.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.menuLanguage.setIcon(icon)
        self.menuLanguage.setObjectName("menuLanguage")
        MainWindow.setMenuBar(self.menubar)
        self.toolBar = QtWidgets.QToolBar(MainWindow)
        self.toolBar.setOrientation(QtCore.Qt.Horizontal)
        self.toolBar.setIconSize(QtCore.QSize(24, 24))
        self.toolBar.setToolButtonStyle(QtCore.Qt.ToolButtonIconOnly)
        self.toolBar.setObjectName("toolBar")
        MainWindow.addToolBar(QtCore.Qt.TopToolBarArea, self.toolBar)
        self.Labels = QtWidgets.QDockWidget(MainWindow)
        font = QtGui.QFont()
        font.setFamily("Times New Roman")
        font.setPointSize(12)
        font.setBold(False)
        font.setItalic(False)
        font.setWeight(50)
        self.Labels.setFont(font)
        self.Labels.setContextMenuPolicy(QtCore.Qt.DefaultContextMenu)
        self.Labels.setAcceptDrops(False)
        self.Labels.setObjectName("Labels")
        self.dockWidgetContents = QtWidgets.QWidget()
        self.dockWidgetContents.setObjectName("dockWidgetContents")
        self.verticalLayout = QtWidgets.QVBoxLayout(self.dockWidgetContents)
        self.verticalLayout.setContentsMargins(3, 3, 3, 3)
        self.verticalLayout.setSpacing(6)
        self.verticalLayout.setObjectName("verticalLayout")
        self.widget = QtWidgets.QWidget(self.dockWidgetContents)
        self.widget.setObjectName("widget")
        self.horizontalLayout = QtWidgets.QHBoxLayout(self.widget)
        self.horizontalLayout.setContentsMargins(-1, 0, -1, 0)
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.checkBox_visiable = QtWidgets.QCheckBox(self.widget)
        self.checkBox_visiable.setStatusTip("")
        self.checkBox_visiable.setObjectName("checkBox_visiable")
        self.horizontalLayout.addWidget(self.checkBox_visiable)
        self.verticalLayout.addWidget(self.widget)
        self.listWidget_labels = QtWidgets.QListWidget(self.dockWidgetContents)
        self.listWidget_labels.setObjectName("listWidget_labels")
        self.verticalLayout.addWidget(self.listWidget_labels)
        self.pushButton_add_manually = QtWidgets.QPushButton(self.dockWidgetContents)
        self.pushButton_add_manually.setObjectName("pushButton_add_manually")
        self.verticalLayout.addWidget(self.pushButton_add_manually)
        self.Labels.setWidget(self.dockWidgetContents)
        MainWindow.addDockWidget(QtCore.Qt.DockWidgetArea(2), self.Labels)
        self.Files = QtWidgets.QDockWidget(MainWindow)
        self.Files.setObjectName("Files")
        self.dockWidgetContents_2 = QtWidgets.QWidget()
        self.dockWidgetContents_2.setObjectName("dockWidgetContents_2")
        self.verticalLayout_2 = QtWidgets.QVBoxLayout(self.dockWidgetContents_2)
        self.verticalLayout_2.setObjectName("verticalLayout_2")
        self.listWidget_files = QtWidgets.QListWidget(self.dockWidgetContents_2)
        self.listWidget_files.setObjectName("listWidget_files")
        self.verticalLayout_2.addWidget(self.listWidget_files)
        self.horizontalLayout_2 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_2.setObjectName("horizontalLayout_2")
        self.lineEdit_jump = QtWidgets.QLineEdit(self.dockWidgetContents_2)
        font = QtGui.QFont()
        font.setFamily("Times New Roman")
        font.setPointSize(12)
        font.setBold(False)
        font.setItalic(False)
        font.setWeight(50)
        self.lineEdit_jump.setFont(font)
        self.lineEdit_jump.setObjectName("lineEdit_jump")
        self.horizontalLayout_2.addWidget(self.lineEdit_jump)
        self.label_files = QtWidgets.QLabel(self.dockWidgetContents_2)
        self.label_files.setMinimumSize(QtCore.QSize(50, 0))
        self.label_files.setText("")
        self.label_files.setTextFormat(QtCore.Qt.AutoText)
        self.label_files.setScaledContents(False)
        self.label_files.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.label_files.setObjectName("label_files")
        self.horizontalLayout_2.addWidget(self.label_files)
        self.verticalLayout_2.addLayout(self.horizontalLayout_2)
        self.Files.setWidget(self.dockWidgetContents_2)
        MainWindow.addDockWidget(QtCore.Qt.DockWidgetArea(2), self.Files)
        self.status_bar = QtWidgets.QStatusBar(MainWindow)
        self.status_bar.setObjectName("status_bar")
        MainWindow.setStatusBar(self.status_bar)
        self.dockWidget = QtWidgets.QDockWidget(MainWindow)
        self.dockWidget.setObjectName("dockWidget")
        self.dockWidgetContents_3 = QtWidgets.QWidget()
        self.dockWidgetContents_3.setObjectName("dockWidgetContents_3")
        self.verticalLayout_3 = QtWidgets.QVBoxLayout(self.dockWidgetContents_3)
        self.verticalLayout_3.setObjectName("verticalLayout_3")
        self.listWidget_categories = QtWidgets.QListWidget(self.dockWidgetContents_3)
        self.listWidget_categories.setObjectName("listWidget_categories")
        self.verticalLayout_3.addWidget(self.listWidget_categories)
        self.dockWidget.setWidget(self.dockWidgetContents_3)
        MainWindow.addDockWidget(QtCore.Qt.DockWidgetArea(1), self.dockWidget)
        self.actionOpen_image_dir = QtWidgets.QAction(MainWindow)
        icon1 = QtGui.QIcon()
        icon1.addPixmap(QtGui.QPixmap(":/icons/icons/照片_pic.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionOpen_image_dir.setIcon(icon1)
        font = QtGui.QFont()
        font.setFamily("Times New Roman")
        font.setPointSize(12)
        self.actionOpen_image_dir.setFont(font)
        self.actionOpen_image_dir.setObjectName("actionOpen_image_dir")
        self.actionOpen_label_dir = QtWidgets.QAction(MainWindow)
        icon2 = QtGui.QIcon()
        icon2.addPixmap(QtGui.QPixmap(":/icons/icons/文件夹-开_folder-open.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionOpen_label_dir.setIcon(icon2)
        self.actionOpen_label_dir.setWhatsThis("")
        font = QtGui.QFont()
        font.setFamily("Times New Roman")
        font.setPointSize(12)
        self.actionOpen_label_dir.setFont(font)
        self.actionOpen_label_dir.setObjectName("actionOpen_label_dir")
        self.actionExit = QtWidgets.QAction(MainWindow)
        icon3 = QtGui.QIcon()
        icon3.addPixmap(QtGui.QPixmap(":/icons/icons/开关_power.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionExit.setIcon(icon3)
        font = QtGui.QFont()
        font.setFamily("Times New Roman")
        font.setPointSize(12)
        self.actionExit.setFont(font)
        self.actionExit.setObjectName("actionExit")
        self.actionZoom_in = QtWidgets.QAction(MainWindow)
        icon4 = QtGui.QIcon()
        icon4.addPixmap(QtGui.QPixmap(":/icons/icons/放大_zoom-in.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionZoom_in.setIcon(icon4)
        font = QtGui.QFont()
        font.setFamily("Times New Roman")
        font.setPointSize(12)
        self.actionZoom_in.setFont(font)
        self.actionZoom_in.setObjectName("actionZoom_in")
        self.actionZoom_out = QtWidgets.QAction(MainWindow)
        icon5 = QtGui.QIcon()
        icon5.addPixmap(QtGui.QPixmap(":/icons/icons/缩小_zoom-out.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionZoom_out.setIcon(icon5)
        font = QtGui.QFont()
        font.setFamily("Times New Roman")
        font.setPointSize(12)
        self.actionZoom_out.setFont(font)
        self.actionZoom_out.setObjectName("actionZoom_out")
        self.actionFit_window = QtWidgets.QAction(MainWindow)
        icon6 = QtGui.QIcon()
        icon6.addPixmap(QtGui.QPixmap(":/icons/icons/全宽_fullwidth.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionFit_window.setIcon(icon6)
        font = QtGui.QFont()
        font.setFamily("Times New Roman")
        font.setPointSize(12)
        self.actionFit_window.setFont(font)
        self.actionFit_window.setObjectName("actionFit_window")
        self.actionCreate = QtWidgets.QAction(MainWindow)
        icon7 = QtGui.QIcon()
        icon7.addPixmap(QtGui.QPixmap(":/icons/icons/锚点_anchor.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionCreate.setIcon(icon7)
        font = QtGui.QFont()
        font.setFamily("Times New Roman")
        font.setPointSize(12)
        self.actionCreate.setFont(font)
        self.actionCreate.setObjectName("actionCreate")
        self.actionEdit = QtWidgets.QAction(MainWindow)
        icon8 = QtGui.QIcon()
        icon8.addPixmap(QtGui.QPixmap(":/icons/icons/编辑文件_file-editing.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionEdit.setIcon(icon8)
        self.actionEdit.setWhatsThis("")
        font = QtGui.QFont()
        font.setFamily("Times New Roman")
        font.setPointSize(12)
        self.actionEdit.setFont(font)
        self.actionEdit.setObjectName("actionEdit")
        self.actionDelete = QtWidgets.QAction(MainWindow)
        icon9 = QtGui.QIcon()
        icon9.addPixmap(QtGui.QPixmap(":/icons/icons/删除_delete.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionDelete.setIcon(icon9)
        self.actionDelete.setWhatsThis("")
        font = QtGui.QFont()
        font.setFamily("Times New Roman")
        font.setPointSize(12)
        self.actionDelete.setFont(font)
        self.actionDelete.setObjectName("actionDelete")
        self.actionSave = QtWidgets.QAction(MainWindow)
        icon10 = QtGui.QIcon()
        icon10.addPixmap(QtGui.QPixmap(":/icons/icons/保存_save.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionSave.setIcon(icon10)
        font = QtGui.QFont()
        font.setFamily("Times New Roman")
        font.setPointSize(12)
        self.actionSave.setFont(font)
        self.actionSave.setObjectName("actionSave")
        self.actionPrior_image = QtWidgets.QAction(MainWindow)
        icon11 = QtGui.QIcon()
        icon11.addPixmap(QtGui.QPixmap(":/icons/icons/上一步_back.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionPrior_image.setIcon(icon11)
        self.actionPrior_image.setStatusTip("")
        font = QtGui.QFont()
        font.setFamily("Times New Roman")
        font.setPointSize(12)
        self.actionPrior_image.setFont(font)
        self.actionPrior_image.setObjectName("actionPrior_image")
        self.actionNext_image = QtWidgets.QAction(MainWindow)
        icon12 = QtGui.QIcon()
        icon12.addPixmap(QtGui.QPixmap(":/icons/icons/下一步_next.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionNext_image.setIcon(icon12)
        font = QtGui.QFont()
        font.setFamily("Times New Roman")
        font.setPointSize(12)
        self.actionNext_image.setFont(font)
        self.actionNext_image.setObjectName("actionNext_image")
        self.actionSetting = QtWidgets.QAction(MainWindow)
        icon13 = QtGui.QIcon()
        icon13.addPixmap(QtGui.QPixmap(":/icons/icons/设置_setting-two.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionSetting.setIcon(icon13)
        font = QtGui.QFont()
        font.setFamily("Times New Roman")
        font.setPointSize(12)
        self.actionSetting.setFont(font)
        self.actionSetting.setObjectName("actionSetting")
        self.actionCache = QtWidgets.QAction(MainWindow)
        icon14 = QtGui.QIcon()
        icon14.addPixmap(QtGui.QPixmap(":/icons/icons/关闭_close-one.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionCache.setIcon(icon14)
        font = QtGui.QFont()
        font.setFamily("Times New Roman")
        font.setPointSize(12)
        self.actionCache.setFont(font)
        self.actionCache.setObjectName("actionCache")
        self.actionShortcut = QtWidgets.QAction(MainWindow)
        icon15 = QtGui.QIcon()
        icon15.addPixmap(QtGui.QPixmap(":/icons/icons/键盘_keyboard-one.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionShortcut.setIcon(icon15)
        font = QtGui.QFont()
        font.setFamily("Times New Roman")
        font.setPointSize(12)
        self.actionShortcut.setFont(font)
        self.actionShortcut.setObjectName("actionShortcut")
        self.actionAbout = QtWidgets.QAction(MainWindow)
        icon16 = QtGui.QIcon()
        icon16.addPixmap(QtGui.QPixmap(":/icons/icons/我的_me.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionAbout.setIcon(icon16)
        font = QtGui.QFont()
        font.setFamily("Times New Roman")
        font.setPointSize(12)
        self.actionAbout.setFont(font)
        self.actionAbout.setObjectName("actionAbout")
        self.actionChinese = QtWidgets.QAction(MainWindow)
        self.actionChinese.setObjectName("actionChinese")
        self.actionEnglish = QtWidgets.QAction(MainWindow)
        self.actionEnglish.setObjectName("actionEnglish")
        self.actionVisible = QtWidgets.QAction(MainWindow)
        self.actionVisible.setCheckable(True)
        icon17 = QtGui.QIcon()
        icon17.addPixmap(QtGui.QPixmap(":/icons/icons/眼睛_eyes.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionVisible.setIcon(icon17)
        font = QtGui.QFont()
        font.setFamily("Times New Roman")
        font.setPointSize(12)
        self.actionVisible.setFont(font)
        self.actionVisible.setObjectName("actionVisible")
        self.menuFile.addAction(self.actionOpen_image_dir)
        self.menuFile.addAction(self.actionOpen_label_dir)
        self.menuFile.addSeparator()
        self.menuFile.addAction(self.actionPrior_image)
        self.menuFile.addAction(self.actionNext_image)
        self.menuFile.addSeparator()
        self.menuFile.addAction(self.actionSetting)
        self.menuFile.addAction(self.actionExit)
        self.menuView.addAction(self.actionFit_window)
        self.menuView.addAction(self.actionZoom_in)
        self.menuView.addAction(self.actionZoom_out)
        self.menuView.addAction(self.actionVisible)
        self.menuEdit.addAction(self.actionCreate)
        self.menuEdit.addAction(self.actionCache)
        self.menuEdit.addAction(self.actionEdit)
        self.menuEdit.addAction(self.actionDelete)
        self.menuEdit.addAction(self.actionSave)
        self.menuLanguage.addAction(self.actionChinese)
        self.menuLanguage.addAction(self.actionEnglish)
        self.menuHelp.addAction(self.menuLanguage.menuAction())
        self.menuHelp.addAction(self.actionShortcut)
        self.menuHelp.addAction(self.actionAbout)
        self.menubar.addAction(self.menuFile.menuAction())
        self.menubar.addAction(self.menuEdit.menuAction())
        self.menubar.addAction(self.menuView.menuAction())
        self.menubar.addAction(self.menuHelp.menuAction())
        self.toolBar.addAction(self.actionOpen_image_dir)
        self.toolBar.addAction(self.actionOpen_label_dir)
        self.toolBar.addSeparator()
        self.toolBar.addAction(self.actionPrior_image)
        self.toolBar.addAction(self.actionNext_image)
        self.toolBar.addSeparator()
        self.toolBar.addAction(self.actionCreate)
        self.toolBar.addAction(self.actionEdit)
        self.toolBar.addAction(self.actionDelete)
        self.toolBar.addAction(self.actionSave)
        self.toolBar.addSeparator()
        self.toolBar.addAction(self.actionFit_window)
        self.toolBar.addAction(self.actionZoom_in)
        self.toolBar.addAction(self.actionZoom_out)
        self.toolBar.addAction(self.actionVisible)

        self.retranslateUi(MainWindow)
        QtCore.QMetaObject.connectSlotsByName(MainWindow)

    def retranslateUi(self, MainWindow):
        _translate = QtCore.QCoreApplication.translate
        MainWindow.setWindowTitle(_translate("MainWindow", "MainWindow"))
        self.menuFile.setTitle(_translate("MainWindow", "File"))
        self.menuView.setTitle(_translate("MainWindow", "View"))
        self.menuEdit.setTitle(_translate("MainWindow", "Edit"))
        self.menuHelp.setTitle(_translate("MainWindow", "Help"))
        self.menuLanguage.setTitle(_translate("MainWindow", "Language"))
        self.toolBar.setWindowTitle(_translate("MainWindow", "toolBar"))
        self.Labels.setWindowTitle(_translate("MainWindow", "Labels Dock"))
        self.checkBox_visiable.setText(_translate("MainWindow", "Visiable"))
        self.pushButton_add_manually.setStatusTip(_translate("MainWindow", "Add annotation manually."))
        self.pushButton_add_manually.setText(_translate("MainWindow", "Add Manually"))
        self.Files.setWindowTitle(_translate("MainWindow", "Files Dock"))
        self.lineEdit_jump.setStatusTip(_translate("MainWindow", "Jump to the image. Input name or index."))
        self.lineEdit_jump.setPlaceholderText(_translate("MainWindow", "Jump to the image."))
        self.dockWidget.setWindowTitle(_translate("MainWindow", "Categories Dock"))
        self.actionOpen_image_dir.setText(_translate("MainWindow", "Image dir"))
        self.actionOpen_image_dir.setStatusTip(_translate("MainWindow", "Open image directory."))
        self.actionOpen_label_dir.setText(_translate("MainWindow", "Label dir"))
        self.actionOpen_label_dir.setStatusTip(_translate("MainWindow", "Open xml file directory. This directory will be used to save xml."))
        self.actionExit.setText(_translate("MainWindow", "Exit"))
        self.actionZoom_in.setText(_translate("MainWindow", "Zoom in "))
        self.actionZoom_out.setText(_translate("MainWindow", "Zoom out"))
        self.actionFit_window.setText(_translate("MainWindow", "Fit window"))
        self.actionFit_window.setStatusTip(_translate("MainWindow", "Resize image to fit window."))
        self.actionFit_window.setShortcut(_translate("MainWindow", "F"))
        self.actionCreate.setText(_translate("MainWindow", "Create"))
        self.actionCreate.setStatusTip(_translate("MainWindow", "Create annotation rectangle."))
        self.actionCreate.setShortcut(_translate("MainWindow", "C"))
        self.actionEdit.setText(_translate("MainWindow", "Edit"))
        self.actionEdit.setStatusTip(_translate("MainWindow", "Edit the selected annotation."))
        self.actionEdit.setShortcut(_translate("MainWindow", "E"))
        self.actionDelete.setText(_translate("MainWindow", "Delete"))
        self.actionDelete.setStatusTip(_translate("MainWindow", "Delect the selected annotation."))
        self.actionDelete.setShortcut(_translate("MainWindow", "Del"))
        self.actionSave.setText(_translate("MainWindow", "Save"))
        self.actionSave.setStatusTip(_translate("MainWindow", "Save current annotation to xml file."))
        self.actionSave.setShortcut(_translate("MainWindow", "S"))
        self.actionPrior_image.setText(_translate("MainWindow", "Prior image"))
        self.actionPrior_image.setShortcut(_translate("MainWindow", "A"))
        self.actionNext_image.setText(_translate("MainWindow", "Next image"))
        self.actionNext_image.setShortcut(_translate("MainWindow", "D"))
        self.actionSetting.setText(_translate("MainWindow", "Setting"))
        self.actionCache.setText(_translate("MainWindow", "Cache"))
        self.actionCache.setShortcut(_translate("MainWindow", "Esc"))
        self.actionShortcut.setText(_translate("MainWindow", "Shortcut"))
        self.actionAbout.setText(_translate("MainWindow", "About"))
        self.actionChinese.setText(_translate("MainWindow", "中文"))
        self.actionEnglish.setText(_translate("MainWindow", "English"))
        self.actionVisible.setText(_translate("MainWindow", "Visible"))
        self.actionVisible.setShortcut(_translate("MainWindow", "V"))

