# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file '/home/super/PycharmProjects/IDAT/add_annotation_dialog.ui'
#
# Created by: PyQt5 UI code generator 5.15.7
#
# WARNING: Any manual changes made to this file will be lost when pyuic5 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_dialog_add_annotation(object):
    def setupUi(self, dialog_add_annotation):
        dialog_add_annotation.setObjectName("dialog_add_annotation")
        dialog_add_annotation.resize(300, 379)
        font = QtGui.QFont()
        font.setFamily("Times New Roman")
        font.setPointSize(12)
        dialog_add_annotation.setFont(font)
        self.verticalLayout = QtWidgets.QVBoxLayout(dialog_add_annotation)
        self.verticalLayout.setObjectName("verticalLayout")
        self.listWidget_category = QtWidgets.QListWidget(dialog_add_annotation)
        self.listWidget_category.setObjectName("listWidget_category")
        self.verticalLayout.addWidget(self.listWidget_category)
        self.lineEdit_category = QtWidgets.QLineEdit(dialog_add_annotation)
        self.lineEdit_category.setReadOnly(True)
        self.lineEdit_category.setObjectName("lineEdit_category")
        self.verticalLayout.addWidget(self.lineEdit_category)
        self.horizontalLayout = QtWidgets.QHBoxLayout()
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.lineEdit_xmin = QtWidgets.QLineEdit(dialog_add_annotation)
        self.lineEdit_xmin.setInputMethodHints(QtCore.Qt.ImhDigitsOnly)
        self.lineEdit_xmin.setObjectName("lineEdit_xmin")
        self.horizontalLayout.addWidget(self.lineEdit_xmin)
        self.lineEdit_ymin = QtWidgets.QLineEdit(dialog_add_annotation)
        self.lineEdit_ymin.setInputMethodHints(QtCore.Qt.ImhDigitsOnly)
        self.lineEdit_ymin.setObjectName("lineEdit_ymin")
        self.horizontalLayout.addWidget(self.lineEdit_ymin)
        self.lineEdit_xmax = QtWidgets.QLineEdit(dialog_add_annotation)
        self.lineEdit_xmax.setInputMethodHints(QtCore.Qt.ImhDigitsOnly)
        self.lineEdit_xmax.setObjectName("lineEdit_xmax")
        self.horizontalLayout.addWidget(self.lineEdit_xmax)
        self.lineEdit_ymax = QtWidgets.QLineEdit(dialog_add_annotation)
        self.lineEdit_ymax.setInputMethodHints(QtCore.Qt.ImhDigitsOnly)
        self.lineEdit_ymax.setCursorMoveStyle(QtCore.Qt.LogicalMoveStyle)
        self.lineEdit_ymax.setObjectName("lineEdit_ymax")
        self.horizontalLayout.addWidget(self.lineEdit_ymax)
        self.verticalLayout.addLayout(self.horizontalLayout)
        self.horizontalLayout_2 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_2.setObjectName("horizontalLayout_2")
        self.checkBox_difficult = QtWidgets.QCheckBox(dialog_add_annotation)
        self.checkBox_difficult.setMinimumSize(QtCore.QSize(0, 0))
        self.checkBox_difficult.setMaximumSize(QtCore.QSize(100, 16777215))
        self.checkBox_difficult.setObjectName("checkBox_difficult")
        self.horizontalLayout_2.addWidget(self.checkBox_difficult)
        spacerItem = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_2.addItem(spacerItem)
        self.pushButton_cache = QtWidgets.QPushButton(dialog_add_annotation)
        self.pushButton_cache.setMinimumSize(QtCore.QSize(80, 0))
        self.pushButton_cache.setMaximumSize(QtCore.QSize(80, 16777215))
        icon = QtGui.QIcon()
        icon.addPixmap(QtGui.QPixmap(":/icons/icons/关闭_close-one.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.pushButton_cache.setIcon(icon)
        self.pushButton_cache.setObjectName("pushButton_cache")
        self.horizontalLayout_2.addWidget(self.pushButton_cache)
        self.pushButton_apply = QtWidgets.QPushButton(dialog_add_annotation)
        self.pushButton_apply.setMinimumSize(QtCore.QSize(80, 0))
        self.pushButton_apply.setMaximumSize(QtCore.QSize(80, 16777215))
        icon1 = QtGui.QIcon()
        icon1.addPixmap(QtGui.QPixmap(":/icons/icons/校验_check-one.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.pushButton_apply.setIcon(icon1)
        self.pushButton_apply.setObjectName("pushButton_apply")
        self.horizontalLayout_2.addWidget(self.pushButton_apply)
        self.verticalLayout.addLayout(self.horizontalLayout_2)

        self.retranslateUi(dialog_add_annotation)
        QtCore.QMetaObject.connectSlotsByName(dialog_add_annotation)

    def retranslateUi(self, dialog_add_annotation):
        _translate = QtCore.QCoreApplication.translate
        dialog_add_annotation.setWindowTitle(_translate("dialog_add_annotation", "Add annotation manually"))
        self.lineEdit_xmin.setPlaceholderText(_translate("dialog_add_annotation", "xmin"))
        self.lineEdit_ymin.setPlaceholderText(_translate("dialog_add_annotation", "ymin"))
        self.lineEdit_xmax.setPlaceholderText(_translate("dialog_add_annotation", "xmax"))
        self.lineEdit_ymax.setPlaceholderText(_translate("dialog_add_annotation", "ymax"))
        self.checkBox_difficult.setText(_translate("dialog_add_annotation", "difficult"))
        self.pushButton_cache.setText(_translate("dialog_add_annotation", "cache"))
        self.pushButton_apply.setText(_translate("dialog_add_annotation", "apply"))
